WARNING: Grom’s gateway is broken and will be fixed whenever the rewrite on the one-module branch is released.
What you can do with grom at the moment:
- Receiving interactions - slash/message/user commands, modals, components, etc.
- Sending HTTP rest calls
What you can’t do with grom at the moment:
- Use the gateway - means you cannot receive any events that aren’t interactions
Hic sunt dracones!
grom
🌟 A Gleamy Discord API Library
Grom is a Discord API wrapper written in Gleam.
It aims to be up-to-date and fully-featured, while also providing an API that is familiar to the Gleam programming language.
Grom is considered experimental, and while it has released as v1.0.0, there are many breaking changes to come. These changes will either stem from the library’s internal changes, or the Discord API’s changes.
Features:
- Support for the Discord v10 gateway - connecting, reconnecting, resuming, heartbeating, sending/receiving events.
-
Full Discord REST API support in the library.
We don’t talk about scheduled events 😂 - Slash/message/user commands, interactions.
- Components v2, along with modal components.
- Using the Erlang target, along with its amazing OTP library.
- Monetization. (untested, hic sunt dracones)
- Sharding.
- Voice support.
- Bearer token authentication.
💻 Examples
You can see the examples here. These will be rolled out over time.
🔨 Contributing
Check out the good first issues!
📃 Documentation
Further documentation can be found at https://hexdocs.pm/grom.