grom
🌟 A Sans-IO Discord REST API Wrapper
Grom is a Discord REST API wrapper written in Gleam.
It aims to be up-to-date and fully-featured, while also providing an API that is familiar to the Gleam programming language.
Grom is considered experimental, and while it has released as v1.0.0, there are many breaking changes to come. These changes will either stem from the library’s internal changes, or the Discord API’s changes.
Features:
- Full Discord REST API support in the library.
- Slash/message/user commands, interactions.
- Components v2, along with modal components.
- Supports all Gleam targets, including the browser.
- Provides decoders and encoders for all objects, allowing you to create custom functionality.
- Bearer token authentication.
💻 Examples
You can see the examples here. These will be rolled out over time.
NOTE: These are currently written for the old version 6. Please don’t depend on them too much.
📋 See also:
- agat - a Discord Gateway client
- nil - a single-node HTTP client for grom
- silent_unseen - a Discord Voice Gateway client
- commandos - an HTTP interactions middleware
📃 Documentation
Further documentation can be found at https://hexdocs.pm/grom.